<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="230"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>Acerca del módulo de audio FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="231"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Módulo de audio FFmpeg para Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="232"/>
        <source>Compiled against:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="245"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="125"/>
        <source>FFmpeg Plugin</source>
        <translation>Módulo FFmpeg</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="127"/>
        <source>FFmpeg Formats</source>
        <translation>Formatos FFmpeg</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="45"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="46"/>
        <source>File size</source>
        <translation>Tamaño del archivo</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="46"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation>Tasa de bits</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Formatos</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows Media Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>Shorten</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Configuración del módulo FFmpeg</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG Audio Layer 3)</translation>
    </message>
</context>
</TS>
